# -*- coding: utf-8 -*-

from django.contrib import admin
from django_admin import ReadOnlyModelAdmin

from equipment.models import (IsolationPointFieldPoolInfo, IsolationPointInfo, IsolationPointUserInfo,
                              ThermometerEquipmentInfo, ThermometerMeasureInfo, ThermometerMeasureLogInfo)


class IsolationPointFieldPoolInfoAdmin(admin.ModelAdmin):
    list_display = ('field_type', 'field_key', 'field_name', 'field_options', 'status', 'updated_at', 'created_at')


class IsolationPointInfoAdmin(admin.ModelAdmin):
    list_display = ('point_id', 'point_name', 'point_measure_window', 'point_fields', 'limit_scene_qrcode_url', 'status', 'updated_at', 'created_at')


class IsolationPointUserInfoAdmin(admin.ModelAdmin):
    list_display = ('point_id', 'user_id', 'fields', 'status', 'updated_at', 'created_at')


class ThermometerEquipmentInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('eqpt_id', 'point_id', 'macid', 'sn', 'active_status', 'active_at', 'ipui_pk', 'name', 'sex', 'birth_stamp', 'age', 'phone', 'remark', 'last_submit_at', 'eqpt_register_status', 'eqpt_register_result', 'status', 'updated_at', 'created_at')
    list_filter = ('point_id', 'status')


class ThermometerMeasureInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('point_id', 'point_measure_ymd', 'point_measure_window', 'macid', 'sn', 'temperature', 'status', 'updated_at', 'created_at')
    list_filter = ('point_id', 'status')


class ThermometerMeasureLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('point_id', 'macid', 'sn', 'name', 'sex', 'birth_stamp', 'phone', 'start_stamp', 'end_stamp', 'temperature', 'temperature_src', 'status', 'updated_at', 'created_at')
    list_filter = ('point_id', 'temperature_src', 'status')


admin.site.register(IsolationPointFieldPoolInfo, IsolationPointFieldPoolInfoAdmin)
admin.site.register(IsolationPointInfo, IsolationPointInfoAdmin)
admin.site.register(IsolationPointUserInfo, IsolationPointUserInfoAdmin)
admin.site.register(ThermometerEquipmentInfo, ThermometerEquipmentInfoAdmin)
admin.site.register(ThermometerMeasureInfo, ThermometerMeasureInfoAdmin)
admin.site.register(ThermometerMeasureLogInfo, ThermometerMeasureLogInfoAdmin)
