# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _


class BaseModelMixin(models.Model):
    status = models.BooleanField(_('status'), default=True, help_text=_('状态'), db_index=True)
    created_at = models.DateTimeField(_('created_at'), auto_now_add=True, editable=True, help_text=_('创建时间'))
    updated_at = models.DateTimeField(_('updated_at'), auto_now=True, editable=True, help_text=_('更新时间'))

    class Meta:
        abstract = True


class SexChoicesMixin(models.Model):
    UNKNOWN = 0
    MALE = 1
    FEMALE = 2

    SEX_TUPLE = (
        (UNKNOWN, '未知'),
        (MALE, '男'),
        (FEMALE, '女'),
    )

    class Meta:
        abstract = True
